@@ -122,6 +122,14 @@ def parse_args(argv):
         help="Remove duplicated reads.",
     )
 
+    parser.add_argument(
+        "--comments",
+        choices=['forward', 'skip', 'wrap'],
+        default='wrap',
+        help="How to treat FASTQ header comments. "
+             "`forward` them 'as is', `wrap` them into 'CO:Z:xxx' tag, `skip` them in the output.",
+    )
+
     parser.add_argument(
         "FASTQ",
         nargs="+",
@@ -174,6 +182,14 @@ def find_file_in_folder(
     return files
 
 
+def parse_timestamp(time_str):
+    try:
+        time_obj = datetime.strptime(time_str,'%Y-%m-%dT%H:%M:%SZ')
+    except ValueError:
+        time_obj = datetime.strptime(time_str,'%Y-%m-%dT%H:%M:%S.%f%z').replace(tzinfo=None)
+    return time_obj
+
+
 def check_seq_time(comment, max_start_time,min_start_time):
     #This tests if the start time of the respective read is between
     #max_sequencing_time and min_sequencing_time
@@ -183,7 +199,7 @@ def check_seq_time(comment, max_start_time,min_start_time):
     else:
         matchObj = re.search( r'start_time=([^ ]+)', comment, re.M|re.I)
         start_str = matchObj.group(1)
-        start = datetime.strptime(start_str,'%Y-%m-%dT%H:%M:%SZ')
+        start = parse_timestamp(start_str)
 
         bool_min=0
         bool_max=0
@@ -203,7 +219,7 @@ def compare_start_time(comment,min_start_time):
     #The smaller time is returned
     matchObj = re.search( r'start_time=([^ ]+)', comment, re.M|re.I)
     start_time_str = matchObj.group(1)
-    start_time = datetime.strptime(start_time_str,'%Y-%m-%dT%H:%M:%SZ')
+    start_time = parse_timestamp(start_time_str)
 
     if(min_start_time==0):
         return start_time
@@ -213,7 +229,7 @@ def compare_start_time(comment,min_start_time):
         return start_time
 
 
-def parse_fastqs(filename, min_len=0, min_qscore=0, max_start_time=None, min_start_time=None):
+def parse_fastqs(filename, min_len=0, min_qscore=0, max_start_time=None, min_start_time=None, comments='wrap'):
     with pysam.FastxFile(filename) as fh:
         for entry in fh:
             if min_len and len(entry.sequence) < min_len:
@@ -225,9 +241,10 @@ def parse_fastqs(filename, min_len=0, min_qscore=0, max_start_time=None, min_sta
                 continue
             if not check_seq_time(entry.comment, max_start_time, min_start_time):
                 continue
-            if entry.comment:
+            if entry.comment and comments == 'wrap':
                 entry.comment = "CO:Z:{}".format(entry.comment)
-
+            elif comments == 'skip':
+                entry.comment = None
             yield entry
 
 
@@ -265,7 +282,7 @@ def get_start_time(paths,recursive=False):
     return min_start_time
 
 
-def format_fq(paths, out_filename, min_len=0, min_qscore=0, max_n=0, max_bp=0, recursive=False, dedup=False, max_seq_time=0, min_seq_time=0, start_time=0, filter_read_ids_file=None):
+def format_fq(paths, out_filename, min_len=0, min_qscore=0, max_n=0, max_bp=0, recursive=False, dedup=False, max_seq_time=0, min_seq_time=0, start_time=0, filter_read_ids_file=None, comments='wrap'):
     """
     Concatenate FASTQ files
 
@@ -289,7 +306,7 @@ def format_fq(paths, out_filename, min_len=0, min_qscore=0, max_n=0, max_bp=0, r
 
     if start_time:
         if not start_time=="min":
-            start = datetime.strptime(start_time,'%Y-%m-%dT%H:%M:%SZ')
+            start = parse_timestamp(start_time)
 
             if(max_seq_time):
                 max_start_time = start + timedelta(minutes=max_seq_time)
@@ -298,7 +315,7 @@ def format_fq(paths, out_filename, min_len=0, min_qscore=0, max_n=0, max_bp=0, r
         else:
             #This option allows to automatically use the minmal start_time of
             #all the given fastq files as input for --start-time
-            auto_start_time=get_start_time(paths,recursive)
+            start=get_start_time(paths,recursive)
 
             if(max_seq_time):
                 max_start_time = start + timedelta(minutes=max_seq_time)
@@ -314,7 +331,7 @@ def format_fq(paths, out_filename, min_len=0, min_qscore=0, max_n=0, max_bp=0, r
             logging.debug("Found {} files".format(len(filenames)))
             for filename in filenames:
                 for entry in parse_fastqs(
-                    filename, min_len=min_len, min_qscore=min_qscore, max_start_time=max_start_time, min_start_time=min_start_time
+                    filename, min_len=min_len, min_qscore=min_qscore, max_start_time=max_start_time, min_start_time=min_start_time, comments=comments
                 ):
                     if dedup and entry.name in read_ids:
                         continue
@@ -363,7 +380,8 @@ def main(argv=sys.argv[1:]):
             max_seq_time=args.MAX_SEQ_TIME,
             min_seq_time=args.MIN_SEQ_TIME,
             start_time=args.START_TIME,
-            filter_read_ids_file=args.FILTER_ID
+            filter_read_ids_file=args.FILTER_ID,
+            comments=args.comments,
         )
 
 
